import { parse } from 'yaml';
import { isFilesystem } from './isFilesystem.js';

/**
 * Normalize the OpenAPI specification to a JavaScript object.
 * Don’t touch the object if it’s a `Filesystem` (multiple files).
 */
function normalize(specification) {
    if (isFilesystem(specification)) {
        return specification;
    }
    if (typeof specification === 'string') {
        try {
            return JSON.parse(specification);
        }
        catch (error) {
            return parse(specification, {
                maxAliasCount: 10000,
            });
        }
    }
    return specification;
}

export { normalize };
